==> flutter_helper-0.0.9.tar.gz: lib/src/Views/ButtonView.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class ButtonView extends StatelessWidget {
  final String text;
  final Function onPressed;
  final Color color;
  final Color contentColor;
  final IconData iconData;
  final double circular;
  final double elevation;
  final MainAxisAlignment mainAxisAlignment;

  ButtonView({
    this.text,
    this.onPressed,
    this.color,
    this.contentColor,
    this.iconData,
    this.circular,
    this.elevation,
    this.mainAxisAlignment
  });

  @override
  Widget build(BuildContext context) {
    final Color accentIconColor =  Theme.of(context).accentIconTheme.color;

    final Color accentColor = Theme.of(context).accentColor;

    return ButtonTheme(
      height: kIsWeb ? 46.0 : 36.0,
      child: RaisedButton(
          padding: EdgeInsets.zero,
          elevation: elevation,
          onPressed: onPressed,
          disabledColor: Colors.grey,
          child: Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10.0),
            child: Row(
              mainAxisAlignment: mainAxisAlignment ?? MainAxisAlignment.center,
              children: [
                iconData != null ? Icon(iconData, color: contentColor ?? accentIconColor) : Container(),
                Padding(
                  padding: const EdgeInsets.only(left: 10.0),
                  child: Text(
                      text,
                      style: TextStyle(
                        color: contentColor ?? accentIconColor,
                        fontSize: 16.0
                      ),
                  ),
                ),
              ],
            ),
          ),
          color: color ?? accentColor,
          shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(circular ?? 2))
      ),
    );
  }
}

==> flutter_helper-0.0.11.tar.gz: lib/src/Views/ButtonView.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class ButtonView extends StatelessWidget {
  final String text;
  final Function onPressed;
  final Color color;
  final Color contentColor;
  final IconData iconData;
  final double circular;
  final double elevation;
  final MainAxisAlignment mainAxisAlignment;

  ButtonView({
    this.text,
    this.onPressed,
    this.color,
    this.contentColor,
    this.iconData,
    this.circular,
    this.elevation,
    this.mainAxisAlignment
  });

  @override
  Widget build(BuildContext context) {
    final Color accentIconColor =  Theme.of(context).accentIconTheme.color;

    final Color accentColor = Theme.of(context).accentColor;

    return ButtonTheme(
      height: kIsWeb ? 45.0 : 40.0,
      child: RaisedButton(
          padding: EdgeInsets.zero,
          elevation: elevation,
          onPressed: onPressed,
          disabledColor: Colors.grey,
          child: Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10.0),
            child: Row(
              mainAxisAlignment: mainAxisAlignment ?? MainAxisAlignment.center,
              children: [
                iconData != null ? Padding(
                  padding: const EdgeInsets.only(right: 10.0),
                  child: Icon(iconData, color: contentColor ?? accentIconColor),
                ) : Container(),
                Text(
                    text,
                    style: TextStyle(
                      color: contentColor ?? accentIconColor,
                      fontSize: 16.0
                    ),
                ),
              ],
            ),
          ),
          color: color ?? accentColor,
          shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(circular ?? 4))
      ),
    );
  }
}
